The NITF data extension header (sarpy.io.general.nitf_elements.des)
===================================================================

.. automodule:: sarpy.io.general.nitf_elements.des
    :members:
    :show-inheritance:
    :inherited-members:
